PRAGMA foreign_keys=OFF;
BEGIN TRANSACTION;
CREATE TABLE experiment_run (
      run_id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER,
      chunk_unit TEXT NOT NULL,
      chunk_size INTEGER NOT NULL,
      completed INTEGER NOT NULL,
      total INTEGER NOT NULL,
      failed INTEGER NOT NULL,
      queuing INTEGER NOT NULL,
      running INTEGER NOT NULL,
      submitted INTEGER NOT NULL,
      suspended INTEGER NOT NULL DEFAULT 0,
      metadata TEXT
      );
INSERT INTO experiment_run VALUES(1,'2023-09-28-14:19:03','2023-09-28-14:19:34',1695903543,1695903574,'month',4,0,22,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01l", "HPCARCH": "local"}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"SIM": {"FILE": "sim", "PLATFORM": "local", "RUNNING": "CHUNK", "DEPENDENCIES": {"SIM-1": {}}, "ADDITIONAL_FILES": []}, "DN": {"FILE": "dn", "PLATFORM": "local", "RUNNING": "CHUNK", "SPLITS": 2, "DEPENDENCIES": {"SIM": {}}, "ADDITIONAL_FILES": []}, "URBAN": {"FILE": "urban", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMAX": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}, "OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "MHM": {"FILE": "mhm", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMAX": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMIN": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": null, "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": null, "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01l", "PROJDIR": "/home/dbeltran/new_autosubmit/a01l/proj/"}');
INSERT INTO experiment_run VALUES(2,'2023-09-28-14:19:34','2023-09-28-14:19:58',1695903574,1695903598,'month',4,0,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01l", "HPCARCH": "local"}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"DN": {"FILE": "dn", "PLATFORM": "local", "RUNNING": "CHUNK", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "URBAN": {"FILE": "urban", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMAX": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}, "OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "MHM": {"FILE": "mhm", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMAX": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMIN": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": null, "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": null, "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01l", "PROJDIR": "/home/dbeltran/new_autosubmit/a01l/proj/"}');
INSERT INTO experiment_run VALUES(3,'2023-09-28-14:19:58','2023-09-29-11:33:03',1695903598,1695979983,'month',4,0,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.93", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01l", "HPCARCH": "local"}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"DN": {"FILE": "dn", "PLATFORM": "local", "RUNNING": "CHUNK", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "URBAN": {"FILE": "urban", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMAX": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}, "OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "MHM": {"FILE": "mhm", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMAX": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMIN": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": null, "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": null, "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01l", "PROJDIR": "/home/dbeltran/new_autosubmit/a01l/proj/"}');
INSERT INTO experiment_run VALUES(4,'2023-09-29-11:33:03','2023-10-04-12:56:02',1695979983,1696416962,'month',4,0,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01l", "HPCARCH": "local"}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"DN": {"FILE": "dn", "PLATFORM": "local", "RUNNING": "CHUNK", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "URBAN": {"FILE": "urban", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMAX": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}, "OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "MHM": {"FILE": "mhm", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMAX": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMIN": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": null, "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": null, "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01l", "PROJDIR": "/home/dbeltran/new_autosubmit/a01l/proj/"}');
INSERT INTO experiment_run VALUES(5,'2023-10-04-12:56:02','2023-10-04-13:06:57',1696416962,1696417617,'month',4,0,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01l", "HPCARCH": "local"}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"DN": {"FILE": "dn", "PLATFORM": "local", "RUNNING": "CHUNK", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "URBAN": {"FILE": "urban", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMAX": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}, "OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "MHM": {"FILE": "mhm", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMAX": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMIN": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": null, "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": null, "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01l", "PROJDIR": "/home/dbeltran/new_autosubmit/a01l/proj/"}');
INSERT INTO experiment_run VALUES(6,'2023-10-04-13:06:57','2023-10-05-09:10:56',1696417617,1696489856,'month',4,0,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01l", "HPCARCH": "local"}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"DN": {"FILE": "dn", "PLATFORM": "local", "RUNNING": "CHUNK", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "URBAN": {"FILE": "urban", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMAX": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}, "OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "MHM": {"FILE": "mhm", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMAX": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMIN": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": null, "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": null, "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01l", "PROJDIR": "/home/dbeltran/new_autosubmit/a01l/proj/"}');
INSERT INTO experiment_run VALUES(7,'2023-10-05-09:10:56','2023-10-05-09:11:46',1696489856,1696489906,'month',4,0,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01l", "HPCARCH": "local"}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"DN": {"FILE": "dn", "PLATFORM": "local", "RUNNING": "CHUNK", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "URBAN": {"FILE": "urban", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMAX": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}, "OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "MHM": {"FILE": "mhm", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMAX": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMIN": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": null, "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": null, "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01l", "PROJDIR": "/home/dbeltran/new_autosubmit/a01l/proj/"}');
INSERT INTO experiment_run VALUES(8,'2023-10-05-09:11:46','2023-10-05-09:13:43',1696489906,1696490023,'month',4,0,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01l", "HPCARCH": "local"}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"DN": {"FILE": "dn", "PLATFORM": "local", "RUNNING": "CHUNK", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "URBAN": {"FILE": "urban", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMAX": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}, "OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "MHM": {"FILE": "mhm", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMAX": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMIN": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": null, "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": null, "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01l", "PROJDIR": "/home/dbeltran/new_autosubmit/a01l/proj/"}');
INSERT INTO experiment_run VALUES(9,'2023-10-05-09:13:43','2023-10-05-09:59:21',1696490023,1696492761,'month',4,0,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01l", "HPCARCH": "local"}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"DN": {"FILE": "dn", "PLATFORM": "local", "RUNNING": "CHUNK", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "URBAN": {"FILE": "urban", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMAX": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}, "OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "MHM": {"FILE": "mhm", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMAX": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMIN": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": null, "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": null, "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01l", "PROJDIR": "/home/dbeltran/new_autosubmit/a01l/proj/"}');
INSERT INTO experiment_run VALUES(10,'2023-10-05-09:59:21','2023-10-05-11:48:23',1696492761,1696499303,'month',4,0,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01l", "HPCARCH": "local"}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"DN": {"FILE": "dn", "PLATFORM": "local", "RUNNING": "CHUNK", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "URBAN": {"FILE": "urban", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMAX": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}, "OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "MHM": {"FILE": "mhm", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMAX": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMIN": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": null, "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": null, "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01l", "PROJDIR": "/home/dbeltran/new_autosubmit/a01l/proj/"}');
INSERT INTO experiment_run VALUES(11,'2023-10-05-11:48:23','2023-10-05-11:53:59',1696499303,1696499639,'month',4,0,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01l", "HPCARCH": "local"}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"DN": {"FILE": "dn", "PLATFORM": "local", "RUNNING": "CHUNK", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "URBAN": {"FILE": "urban", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMAX": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}, "OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "MHM": {"FILE": "mhm", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMAX": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMIN": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": null, "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": null, "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01l", "PROJDIR": "/home/dbeltran/new_autosubmit/a01l/proj/"}');
INSERT INTO experiment_run VALUES(12,'2023-10-05-11:53:59','2023-10-05-14:13:17',1696499639,1696507997,'month',4,0,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01l", "HPCARCH": "local"}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"DN": {"FILE": "dn", "PLATFORM": "local", "RUNNING": "CHUNK", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "URBAN": {"FILE": "urban", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMAX": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}, "OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "MHM": {"FILE": "mhm", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMAX": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMIN": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": null, "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": null, "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01l", "PROJDIR": "/home/dbeltran/new_autosubmit/a01l/proj/"}');
INSERT INTO experiment_run VALUES(13,'2023-10-05-14:13:17','2023-10-05-14:13:41',1696507997,1696508021,'month',4,0,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01l", "HPCARCH": "local"}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"DN": {"FILE": "dn", "PLATFORM": "local", "RUNNING": "CHUNK", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "URBAN": {"FILE": "urban", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMAX": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}, "OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "MHM": {"FILE": "mhm", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMAX": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMIN": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": null, "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": null, "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01l", "PROJDIR": "/home/dbeltran/new_autosubmit/a01l/proj/"}');
INSERT INTO experiment_run VALUES(14,'2023-10-05-14:13:41','2023-10-05-14:14:21',1696508021,1696508061,'month',4,0,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.96", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01l", "HPCARCH": "local"}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"DN": {"FILE": "dn", "PLATFORM": "local", "RUNNING": "CHUNK", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "URBAN": {"FILE": "urban", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMAX": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}, "OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "MHM": {"FILE": "mhm", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMAX": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMIN": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": null, "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": null, "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01l", "PROJDIR": "/home/dbeltran/new_autosubmit/a01l/proj/"}');
INSERT INTO experiment_run VALUES(15,'2023-10-05-14:14:21','2023-10-05-14:15:21',1696508061,1696508121,'month',4,0,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.96", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01l", "HPCARCH": "local"}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"DN": {"FILE": "dn", "PLATFORM": "local", "RUNNING": "CHUNK", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "URBAN": {"FILE": "urban", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMAX": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}, "OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "MHM": {"FILE": "mhm", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMAX": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMIN": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": null, "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": null, "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01l", "PROJDIR": "/home/dbeltran/new_autosubmit/a01l/proj/"}');
INSERT INTO experiment_run VALUES(16,'2023-10-05-14:15:21','2023-10-05-14:15:40',1696508121,1696508140,'month',4,0,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01l", "HPCARCH": "local"}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"DN": {"FILE": "dn", "PLATFORM": "local", "RUNNING": "CHUNK", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "URBAN": {"FILE": "urban", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMAX": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}, "OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "MHM": {"FILE": "mhm", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMAX": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMIN": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": null, "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": null, "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01l", "PROJDIR": "/home/dbeltran/new_autosubmit/a01l/proj/"}');
INSERT INTO experiment_run VALUES(17,'2023-10-05-14:15:40','2023-10-05-14:22:45',1696508140,1696508565,'month',4,0,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01l", "HPCARCH": "local"}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"DN": {"FILE": "dn", "PLATFORM": "local", "RUNNING": "CHUNK", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "URBAN": {"FILE": "urban", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMAX": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}, "OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "MHM": {"FILE": "mhm", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMAX": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMIN": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": null, "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": null, "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01l", "PROJDIR": "/home/dbeltran/new_autosubmit/a01l/proj/"}');
INSERT INTO experiment_run VALUES(18,'2023-10-05-14:22:45','2023-10-05-14:39:41',1696508565,1696509581,'month',4,0,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01l", "HPCARCH": "local"}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"DN": {"FILE": "dn", "PLATFORM": "local", "RUNNING": "CHUNK", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "URBAN": {"FILE": "urban", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMAX": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}, "OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "MHM": {"FILE": "mhm", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMAX": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMIN": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": null, "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": null, "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01l", "PROJDIR": "/home/dbeltran/new_autosubmit/a01l/proj/"}');
INSERT INTO experiment_run VALUES(19,'2023-10-05-14:39:41','2023-10-05-14:42:28',1696509581,1696509748,'month',4,0,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01l", "HPCARCH": "local"}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"DN": {"FILE": "dn", "PLATFORM": "local", "RUNNING": "CHUNK", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "URBAN": {"FILE": "urban", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMAX": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}, "OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "MHM": {"FILE": "mhm", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMAX": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMIN": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": null, "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": null, "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01l", "PROJDIR": "/home/dbeltran/new_autosubmit/a01l/proj/"}');
INSERT INTO experiment_run VALUES(20,'2023-10-05-14:42:28','2023-10-05-14:47:51',1696509748,1696510071,'month',4,0,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01l", "HPCARCH": "local"}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"DN": {"FILE": "dn", "PLATFORM": "local", "RUNNING": "CHUNK", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "URBAN": {"FILE": "urban", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMAX": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}, "OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "MHM": {"FILE": "mhm", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMAX": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMIN": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": null, "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": null, "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01l", "PROJDIR": "/home/dbeltran/new_autosubmit/a01l/proj/"}');
INSERT INTO experiment_run VALUES(21,'2023-10-05-14:47:51','2023-10-05-14:51:31',1696510071,1696510291,'month',4,0,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01l", "HPCARCH": "local"}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"DN": {"FILE": "dn", "PLATFORM": "local", "RUNNING": "CHUNK", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "URBAN": {"FILE": "urban", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMAX": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}, "OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "MHM": {"FILE": "mhm", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMAX": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMIN": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": null, "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": null, "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01l", "PROJDIR": "/home/dbeltran/new_autosubmit/a01l/proj/"}');
INSERT INTO experiment_run VALUES(22,'2023-10-05-14:51:31','2023-10-05-14:58:51',1696510291,1696510731,'month',4,0,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01l", "HPCARCH": "local"}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"DN": {"FILE": "dn", "PLATFORM": "local", "RUNNING": "CHUNK", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "URBAN": {"FILE": "urban", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMAX": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}, "OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "MHM": {"FILE": "mhm", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMAX": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMIN": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": null, "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": null, "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01l", "PROJDIR": "/home/dbeltran/new_autosubmit/a01l/proj/"}');
INSERT INTO experiment_run VALUES(23,'2023-10-05-14:58:51','2023-10-05-14:59:21',1696510731,1696510761,'month',4,0,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01l", "HPCARCH": "local"}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"DN": {"FILE": "dn", "PLATFORM": "local", "RUNNING": "CHUNK", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "URBAN": {"FILE": "urban", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMAX": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}, "OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "MHM": {"FILE": "mhm", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMAX": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMIN": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": null, "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": null, "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01l", "PROJDIR": "/home/dbeltran/new_autosubmit/a01l/proj/"}');
INSERT INTO experiment_run VALUES(24,'2023-10-05-14:59:21','2023-10-05-14:59:58',1696510761,1696510798,'month',4,0,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01l", "HPCARCH": "local"}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"DN": {"FILE": "dn", "PLATFORM": "local", "RUNNING": "CHUNK", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "URBAN": {"FILE": "urban", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMAX": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}, "OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "MHM": {"FILE": "mhm", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMAX": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMIN": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": null, "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": null, "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01l", "PROJDIR": "/home/dbeltran/new_autosubmit/a01l/proj/"}');
INSERT INTO experiment_run VALUES(25,'2023-10-05-14:59:58','2023-10-05-15:03:38',1696510798,1696511018,'month',4,0,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01l", "HPCARCH": "local"}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"DN": {"FILE": "dn", "PLATFORM": "local", "RUNNING": "CHUNK", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "URBAN": {"FILE": "urban", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMAX": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}, "OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "MHM": {"FILE": "mhm", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMAX": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMIN": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": null, "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": null, "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01l", "PROJDIR": "/home/dbeltran/new_autosubmit/a01l/proj/"}');
INSERT INTO experiment_run VALUES(26,'2023-10-05-15:03:38','2023-10-05-15:14:16',1696511018,1696511656,'month',4,0,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01l", "HPCARCH": "local"}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"DN": {"FILE": "dn", "PLATFORM": "local", "RUNNING": "CHUNK", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "URBAN": {"FILE": "urban", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMAX": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}, "OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "MHM": {"FILE": "mhm", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMAX": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMIN": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": null, "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": null, "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01l", "PROJDIR": "/home/dbeltran/new_autosubmit/a01l/proj/"}');
INSERT INTO experiment_run VALUES(27,'2023-10-05-15:14:16','2023-10-05-15:14:20',1696511656,1696511660,'month',4,0,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01l", "HPCARCH": "local"}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"DN": {"FILE": "dn", "PLATFORM": "local", "RUNNING": "CHUNK", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "URBAN": {"FILE": "urban", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMAX": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}, "OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "MHM": {"FILE": "mhm", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMAX": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMIN": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": null, "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": null, "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01l", "PROJDIR": "/home/dbeltran/new_autosubmit/a01l/proj/"}');
INSERT INTO experiment_run VALUES(28,'2023-10-05-15:14:20','2023-10-05-16:10:38',1696511660,1696515038,'month',4,0,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01l", "HPCARCH": "local"}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"DN": {"FILE": "dn", "PLATFORM": "local", "RUNNING": "CHUNK", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "URBAN": {"FILE": "urban", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMAX": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}, "OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "MHM": {"FILE": "mhm", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMAX": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMIN": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": null, "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": null, "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01l", "PROJDIR": "/home/dbeltran/new_autosubmit/a01l/proj/"}');
INSERT INTO experiment_run VALUES(29,'2023-10-05-16:10:38','2023-10-05-16:11:09',1696515038,1696515069,'month',4,0,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.96", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01l", "HPCARCH": "local"}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"DN": {"FILE": "dn", "PLATFORM": "local", "RUNNING": "CHUNK", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "URBAN": {"FILE": "urban", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMAX": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}, "OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "MHM": {"FILE": "mhm", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMAX": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMIN": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": null, "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": null, "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01l", "PROJDIR": "/home/dbeltran/new_autosubmit/a01l/proj/"}');
INSERT INTO experiment_run VALUES(30,'2023-10-05-16:11:09','2023-10-05-16:12:26',1696515069,1696515146,'month',4,0,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.96", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01l", "HPCARCH": "local"}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"DN": {"FILE": "dn", "PLATFORM": "local", "RUNNING": "CHUNK", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "URBAN": {"FILE": "urban", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMAX": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}, "OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "MHM": {"FILE": "mhm", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMAX": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMIN": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": null, "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": null, "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01l", "PROJDIR": "/home/dbeltran/new_autosubmit/a01l/proj/"}');
INSERT INTO experiment_run VALUES(31,'2023-10-05-16:12:26','2023-10-05-16:12:59',1696515146,1696515179,'month',4,0,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.96", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01l", "HPCARCH": "local"}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"DN": {"FILE": "dn", "PLATFORM": "local", "RUNNING": "CHUNK", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "URBAN": {"FILE": "urban", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMAX": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}, "OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "MHM": {"FILE": "mhm", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMAX": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMIN": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": null, "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": null, "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01l", "PROJDIR": "/home/dbeltran/new_autosubmit/a01l/proj/"}');
INSERT INTO experiment_run VALUES(32,'2023-10-05-16:12:59','2023-10-06-10:29:35',1696515179,1696580975,'month',4,20,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.96", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01l", "HPCARCH": "local"}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"DN": {"FILE": "dn", "PLATFORM": "local", "RUNNING": "CHUNK", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "URBAN": {"FILE": "urban", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMAX": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}, "OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "MHM": {"FILE": "mhm", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMAX": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMIN": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": null, "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": null, "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01l", "PROJDIR": "/home/dbeltran/new_autosubmit/a01l/proj/"}');
INSERT INTO experiment_run VALUES(33,'2023-10-06-10:29:35','2023-10-09-10:42:18',1696580975,1696840938,'month',4,20,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.96", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01l", "HPCARCH": "local"}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"DN": {"FILE": "dn", "PLATFORM": "local", "RUNNING": "CHUNK", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "URBAN": {"FILE": "urban", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMAX": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}, "OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "MHM": {"FILE": "mhm", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMAX": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMIN": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": null, "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": null, "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01l", "PROJDIR": "/home/dbeltran/new_autosubmit/a01l/proj/"}');
INSERT INTO experiment_run VALUES(34,'2023-10-09-10:42:18','2023-10-10-10:47:35',1696840938,1696927655,'month',4,0,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01l", "HPCARCH": "local"}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"DN": {"FILE": "dn", "PLATFORM": "local", "RUNNING": "CHUNK", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "URBAN": {"FILE": "urban", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMAX": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}, "OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "MHM": {"FILE": "mhm", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMAX": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMIN": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": null, "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": null, "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01l", "PROJDIR": "/home/dbeltran/new_autosubmit/a01l/proj/"}');
INSERT INTO experiment_run VALUES(35,'2023-10-10-10:47:35','2023-10-10-11:00:41',1696927655,1696928441,'month',4,0,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01l", "HPCARCH": "local"}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"DN": {"FILE": "dn", "PLATFORM": "local", "RUNNING": "CHUNK", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "URBAN": {"FILE": "urban", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMAX": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}, "OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "MHM": {"FILE": "mhm", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMAX": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMIN": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": null, "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": null, "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01l", "PROJDIR": "/home/dbeltran/new_autosubmit/a01l/proj/"}');
INSERT INTO experiment_run VALUES(36,'2023-10-10-11:00:41','2023-10-10-11:09:32',1696928441,1696928972,'month',4,0,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01l", "HPCARCH": "local"}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"DN": {"FILE": "dn", "PLATFORM": "local", "RUNNING": "CHUNK", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "URBAN": {"FILE": "urban", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMAX": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}, "OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "MHM": {"FILE": "mhm", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMAX": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMIN": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": null, "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": null, "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01l", "PROJDIR": "/home/dbeltran/new_autosubmit/a01l/proj/"}');
INSERT INTO experiment_run VALUES(37,'2023-10-10-11:09:32','2023-10-10-11:11:45',1696928972,1696929105,'month',4,0,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01l", "HPCARCH": "local"}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"DN": {"FILE": "dn", "PLATFORM": "local", "RUNNING": "CHUNK", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "URBAN": {"FILE": "urban", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMAX": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}, "OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "MHM": {"FILE": "mhm", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMAX": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMIN": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": null, "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": null, "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01l", "PROJDIR": "/home/dbeltran/new_autosubmit/a01l/proj/"}');
INSERT INTO experiment_run VALUES(38,'2023-10-10-11:11:45','2023-10-10-11:11:45',1696929105,0,'month',4,0,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01l", "HPCARCH": "local"}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"DN": {"FILE": "dn", "PLATFORM": "local", "RUNNING": "CHUNK", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "URBAN": {"FILE": "urban", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMAX": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}, "OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "MHM": {"FILE": "mhm", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMIN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMAX": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMIN": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": null, "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": null, "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01l", "PROJDIR": "/home/dbeltran/new_autosubmit/a01l/proj/"}');
CREATE TABLE job_data (
      id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      counter INTEGER NOT NULL,
      job_name TEXT NOT NULL,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      submit INTEGER NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER NOT NULL,
      status TEXT NOT NULL,
      rowtype INTEGER NOT NULL,
      ncpus INTEGER NOT NULL,
      wallclock TEXT NOT NULL,
      qos TEXT NOT NULL,
      energy INTEGER NOT NULL,
      date TEXT NOT NULL,
      section TEXT NOT NULL,
      member TEXT NOT NULL,
      chunk INTEGER NOT NULL,
      last INTEGER NOT NULL,
      platform TEXT NOT NULL,
      job_id INTEGER NOT NULL,
      extra_data TEXT NOT NULL,
      nnodes INTEGER NOT NULL DEFAULT 0,
      run_id INTEGER,
      MaxRSS REAL NOT NULL DEFAULT 0.0,
      AveRSS REAL NOT NULL DEFAULT 0.0,
      out TEXT NOT NULL,
      err TEXT NOT NULL,
      rowstatus INTEGER NOT NULL DEFAULT 0,
      children TEXT,
      platform_output TEXT,
      UNIQUE(counter,job_name)
      );
INSERT INTO job_data VALUES(1,0,'a01l_20000101_fc0_1_1_DN','2023-10-05-16:13:05','2023-10-06-10:29:40',1696515185,1696515185,1696515190,'COMPLETED',2,1,'00:00','debug',0,'2000-01-01 00:00:00','DN','fc0',1,0,'LOCAL',42666,'',0,32,0.0,0.0,'a01l_20000101_fc0_1_1_DN.20231005161323.out','a01l_20000101_fc0_1_1_DN.20231005161323.err',5,'a01l_20000101_fc0_1_1_OPA_2TMIN,a01l_20000101_fc0_1_1_OPA_2TMAX','');
INSERT INTO job_data VALUES(2,0,'a01l_20000101_fc0_1_2_DN','2023-10-05-16:13:05','2023-10-06-10:29:40',1696515185,1696515185,1696515190,'COMPLETED',2,1,'00:00','debug',0,'2000-01-01 00:00:00','DN','fc0',1,0,'LOCAL',42688,'',0,32,0.0,0.0,'a01l_20000101_fc0_1_2_DN.20231005161324.out','a01l_20000101_fc0_1_2_DN.20231005161324.err',5,'a01l_20000101_fc0_1_2_OPA_2TMAX,a01l_20000101_fc0_1_2_OPA_2TMIN','');
INSERT INTO job_data VALUES(3,0,'a01l_20000101_fc0_2_1_DN','2023-10-05-16:13:05','2023-10-06-10:29:40',1696515185,1696515185,1696515190,'COMPLETED',2,1,'00:00','debug',0,'2000-01-01 00:00:00','DN','fc0',2,0,'LOCAL',42710,'',0,32,0.0,0.0,'a01l_20000101_fc0_2_1_DN.20231005161324.out','a01l_20000101_fc0_2_1_DN.20231005161324.err',5,'a01l_20000101_fc0_2_1_OPA_2TMAX,a01l_20000101_fc0_2_1_OPA_2TMIN','');
INSERT INTO job_data VALUES(4,0,'a01l_20000101_fc0_2_2_DN','2023-10-05-16:13:05','2023-10-06-10:29:40',1696515185,1696515185,1696515190,'COMPLETED',2,1,'00:00','debug',0,'2000-01-01 00:00:00','DN','fc0',2,0,'LOCAL',42732,'',0,32,0.0,0.0,'a01l_20000101_fc0_2_2_DN.20231005161324.out','a01l_20000101_fc0_2_2_DN.20231005161324.err',5,'a01l_20000101_fc0_2_2_OPA_2TMAX,a01l_20000101_fc0_2_2_OPA_2TMIN','');
INSERT INTO job_data VALUES(5,0,'a01l_20000101_fc0_1_1_OPA_2TMIN','2023-10-05-16:13:24','2023-10-06-10:29:59',1696515204,1696515204,1696515209,'COMPLETED',2,1,'00:00','debug',0,'2000-01-01 00:00:00','OPA_2TMIN','fc0',1,0,'LOCAL',42800,'',0,32,0.0,0.0,'a01l_20000101_fc0_1_1_OPA_2TMIN.20231005161351.out','a01l_20000101_fc0_1_1_OPA_2TMIN.20231005161351.err',5,'a01l_20000101_fc0_1_1_MHM,a01l_20000101_fc0_1_1_URBAN','');
INSERT INTO job_data VALUES(6,0,'a01l_20000101_fc0_1_2_OPA_2TMIN','2023-10-05-16:13:24','2023-10-06-10:29:59',1696515204,1696515204,1696515209,'COMPLETED',2,1,'00:00','debug',0,'2000-01-01 00:00:00','OPA_2TMIN','fc0',1,0,'LOCAL',42822,'',0,32,0.0,0.0,'a01l_20000101_fc0_1_2_OPA_2TMIN.20231005161351.out','a01l_20000101_fc0_1_2_OPA_2TMIN.20231005161351.err',5,'a01l_20000101_fc0_1_2_MHM,a01l_20000101_fc0_1_2_URBAN','');
INSERT INTO job_data VALUES(7,0,'a01l_20000101_fc0_2_1_OPA_2TMIN','2023-10-05-16:13:24','2023-10-06-10:30:00',1696515204,1696515204,1696515209,'COMPLETED',2,1,'00:00','debug',0,'2000-01-01 00:00:00','OPA_2TMIN','fc0',2,0,'LOCAL',42844,'',0,32,0.0,0.0,'a01l_20000101_fc0_2_1_OPA_2TMIN.20231005161351.out','a01l_20000101_fc0_2_1_OPA_2TMIN.20231005161351.err',5,'a01l_20000101_fc0_2_1_URBAN,a01l_20000101_fc0_2_1_MHM','');
INSERT INTO job_data VALUES(8,0,'a01l_20000101_fc0_2_2_OPA_2TMIN','2023-10-05-16:13:24','2023-10-06-10:30:00',1696515204,1696515204,1696515209,'COMPLETED',2,1,'00:00','debug',0,'2000-01-01 00:00:00','OPA_2TMIN','fc0',2,0,'LOCAL',42866,'',0,32,0.0,0.0,'a01l_20000101_fc0_2_2_OPA_2TMIN.20231005161352.out','a01l_20000101_fc0_2_2_OPA_2TMIN.20231005161352.err',5,'a01l_20000101_fc0_2_2_URBAN,a01l_20000101_fc0_2_2_MHM','');
INSERT INTO job_data VALUES(9,0,'a01l_20000101_fc0_1_1_OPA_2TMAX','2023-10-05-16:13:24','2023-10-06-10:30:00',1696515204,1696515204,1696515209,'COMPLETED',2,1,'00:00','debug',0,'2000-01-01 00:00:00','OPA_2TMAX','fc0',1,0,'LOCAL',42888,'',0,32,0.0,0.0,'a01l_20000101_fc0_1_1_OPA_2TMAX.20231005161351.out','a01l_20000101_fc0_1_1_OPA_2TMAX.20231005161351.err',5,'a01l_20000101_fc0_1_1_URBAN','');
INSERT INTO job_data VALUES(10,0,'a01l_20000101_fc0_1_2_OPA_2TMAX','2023-10-05-16:13:24','2023-10-06-10:30:00',1696515204,1696515204,1696515209,'COMPLETED',2,1,'00:00','debug',0,'2000-01-01 00:00:00','OPA_2TMAX','fc0',1,0,'LOCAL',42910,'',0,32,0.0,0.0,'a01l_20000101_fc0_1_2_OPA_2TMAX.20231005161351.out','a01l_20000101_fc0_1_2_OPA_2TMAX.20231005161351.err',5,'a01l_20000101_fc0_1_2_URBAN','');
INSERT INTO job_data VALUES(11,0,'a01l_20000101_fc0_2_1_OPA_2TMAX','2023-10-05-16:13:24','2023-10-06-10:30:00',1696515204,1696515204,1696515209,'COMPLETED',2,1,'00:00','debug',0,'2000-01-01 00:00:00','OPA_2TMAX','fc0',2,0,'LOCAL',42932,'',0,32,0.0,0.0,'a01l_20000101_fc0_2_1_OPA_2TMAX.20231005161351.out','a01l_20000101_fc0_2_1_OPA_2TMAX.20231005161351.err',5,'a01l_20000101_fc0_2_1_URBAN','');
INSERT INTO job_data VALUES(12,0,'a01l_20000101_fc0_2_2_OPA_2TMAX','2023-10-05-16:13:25','2023-10-06-10:30:00',1696515205,1696515205,1696515210,'COMPLETED',2,1,'00:00','debug',0,'2000-01-01 00:00:00','OPA_2TMAX','fc0',2,0,'LOCAL',42954,'',0,32,0.0,0.0,'a01l_20000101_fc0_2_2_OPA_2TMAX.20231005161351.out','a01l_20000101_fc0_2_2_OPA_2TMAX.20231005161351.err',5,'a01l_20000101_fc0_2_2_URBAN','');
INSERT INTO job_data VALUES(13,0,'a01l_20000101_fc0_1_1_MHM','2023-10-05-16:13:52','2023-10-06-10:30:28',1696515232,1696515232,1696515237,'COMPLETED',2,1,'00:00','debug',0,'2000-01-01 00:00:00','MHM','fc0',1,0,'LOCAL',43162,'',0,32,0.0,0.0,'a01l_20000101_fc0_1_1_MHM.20231005161419.out','a01l_20000101_fc0_1_1_MHM.20231005161419.err',5,'','');
INSERT INTO job_data VALUES(14,0,'a01l_20000101_fc0_1_2_MHM','2023-10-05-16:13:52','2023-10-06-10:30:28',1696515232,1696515232,1696515237,'COMPLETED',2,1,'00:00','debug',0,'2000-01-01 00:00:00','MHM','fc0',1,0,'LOCAL',43184,'',0,32,0.0,0.0,'a01l_20000101_fc0_1_2_MHM.20231005161419.out','a01l_20000101_fc0_1_2_MHM.20231005161419.err',5,'','');
INSERT INTO job_data VALUES(15,0,'a01l_20000101_fc0_2_1_MHM','2023-10-05-16:13:52','2023-10-06-10:30:28',1696515232,1696515232,1696515237,'COMPLETED',2,1,'00:00','debug',0,'2000-01-01 00:00:00','MHM','fc0',2,0,'LOCAL',43206,'',0,32,0.0,0.0,'a01l_20000101_fc0_2_1_MHM.20231005161419.out','a01l_20000101_fc0_2_1_MHM.20231005161419.err',5,'','');
INSERT INTO job_data VALUES(16,0,'a01l_20000101_fc0_2_2_MHM','2023-10-05-16:13:52','2023-10-06-10:30:28',1696515232,1696515232,1696515237,'COMPLETED',2,1,'00:00','debug',0,'2000-01-01 00:00:00','MHM','fc0',2,0,'LOCAL',43228,'',0,32,0.0,0.0,'a01l_20000101_fc0_2_2_MHM.20231005161419.out','a01l_20000101_fc0_2_2_MHM.20231005161419.err',5,'','');
INSERT INTO job_data VALUES(17,0,'a01l_20000101_fc0_1_1_URBAN','2023-10-05-16:13:52','2023-10-06-10:30:28',1696515232,1696515232,1696515237,'COMPLETED',2,1,'00:00','debug',0,'2000-01-01 00:00:00','URBAN','fc0',1,0,'LOCAL',43250,'',0,32,0.0,0.0,'a01l_20000101_fc0_1_1_URBAN.20231005161419.out','a01l_20000101_fc0_1_1_URBAN.20231005161419.err',5,'','');
INSERT INTO job_data VALUES(18,0,'a01l_20000101_fc0_1_2_URBAN','2023-10-05-16:13:52','2023-10-06-10:30:29',1696515232,1696515232,1696515237,'COMPLETED',2,1,'00:00','debug',0,'2000-01-01 00:00:00','URBAN','fc0',1,0,'LOCAL',43272,'',0,32,0.0,0.0,'a01l_20000101_fc0_1_2_URBAN.20231005161419.out','a01l_20000101_fc0_1_2_URBAN.20231005161419.err',5,'','');
INSERT INTO job_data VALUES(19,0,'a01l_20000101_fc0_2_1_URBAN','2023-10-05-16:13:52','2023-10-06-10:30:29',1696515232,1696515232,1696515237,'COMPLETED',2,1,'00:00','debug',0,'2000-01-01 00:00:00','URBAN','fc0',2,0,'LOCAL',43294,'',0,32,0.0,0.0,'a01l_20000101_fc0_2_1_URBAN.20231005161419.out','a01l_20000101_fc0_2_1_URBAN.20231005161419.err',5,'','');
INSERT INTO job_data VALUES(20,0,'a01l_20000101_fc0_2_2_URBAN','2023-10-05-16:13:52','2023-10-06-10:30:29',1696515232,1696515232,1696515237,'COMPLETED',2,1,'00:00','debug',0,'2000-01-01 00:00:00','URBAN','fc0',2,0,'LOCAL',43316,'',0,32,0.0,0.0,'a01l_20000101_fc0_2_2_URBAN.20231005161419.out','a01l_20000101_fc0_2_2_URBAN.20231005161419.err',5,'','');
INSERT INTO job_data VALUES(21,1,'a01l_20000101_fc0_1_1_DN','2023-10-06-10:29:40','2023-10-06-10:29:59',1696580980,1696580980,1696580985,'COMPLETED',2,1,'00:00','debug',0,'2000-01-01 00:00:00','DN','fc0',1,1,'LOCAL',17545,'',0,33,0.0,0.0,'a01l_20000101_fc0_1_1_DN.20231006102959.out','a01l_20000101_fc0_1_1_DN.20231006102959.err',5,'a01l_20000101_fc0_1_1_OPA_2TMIN,a01l_20000101_fc0_1_1_OPA_2TMAX','');
INSERT INTO job_data VALUES(22,1,'a01l_20000101_fc0_1_2_DN','2023-10-06-10:29:40','2023-10-06-10:29:59',1696580980,1696580980,1696580985,'COMPLETED',2,1,'00:00','debug',0,'2000-01-01 00:00:00','DN','fc0',1,1,'LOCAL',17567,'',0,33,0.0,0.0,'a01l_20000101_fc0_1_2_DN.20231006102959.out','a01l_20000101_fc0_1_2_DN.20231006102959.err',5,'a01l_20000101_fc0_1_2_OPA_2TMAX,a01l_20000101_fc0_1_2_OPA_2TMIN','');
INSERT INTO job_data VALUES(23,1,'a01l_20000101_fc0_2_1_DN','2023-10-06-10:29:40','2023-10-06-10:29:59',1696580980,1696580980,1696580985,'COMPLETED',2,1,'00:00','debug',0,'2000-01-01 00:00:00','DN','fc0',2,1,'LOCAL',17589,'',0,33,0.0,0.0,'a01l_20000101_fc0_2_1_DN.20231006102959.out','a01l_20000101_fc0_2_1_DN.20231006102959.err',5,'a01l_20000101_fc0_2_1_OPA_2TMAX,a01l_20000101_fc0_2_1_OPA_2TMIN','');
INSERT INTO job_data VALUES(24,1,'a01l_20000101_fc0_2_2_DN','2023-10-06-10:29:40','2023-10-06-10:29:59',1696580980,1696580980,1696580985,'COMPLETED',2,1,'00:00','debug',0,'2000-01-01 00:00:00','DN','fc0',2,1,'LOCAL',17611,'',0,33,0.0,0.0,'a01l_20000101_fc0_2_2_DN.20231006102959.out','a01l_20000101_fc0_2_2_DN.20231006102959.err',5,'a01l_20000101_fc0_2_2_OPA_2TMAX,a01l_20000101_fc0_2_2_OPA_2TMIN','');
INSERT INTO job_data VALUES(25,1,'a01l_20000101_fc0_1_1_OPA_2TMIN','2023-10-06-10:29:59','2023-10-06-10:30:27',1696580999,1696580999,1696581004,'COMPLETED',2,1,'00:00','debug',0,'2000-01-01 00:00:00','OPA_2TMIN','fc0',1,1,'LOCAL',17720,'',0,33,0.0,0.0,'a01l_20000101_fc0_1_1_OPA_2TMIN.20231006103027.out','a01l_20000101_fc0_1_1_OPA_2TMIN.20231006103027.err',5,'a01l_20000101_fc0_1_1_MHM,a01l_20000101_fc0_1_1_URBAN','');
INSERT INTO job_data VALUES(26,1,'a01l_20000101_fc0_1_2_OPA_2TMIN','2023-10-06-10:29:59','2023-10-06-10:30:27',1696580999,1696580999,1696581004,'COMPLETED',2,1,'00:00','debug',0,'2000-01-01 00:00:00','OPA_2TMIN','fc0',1,1,'LOCAL',17742,'',0,33,0.0,0.0,'a01l_20000101_fc0_1_2_OPA_2TMIN.20231006103027.out','a01l_20000101_fc0_1_2_OPA_2TMIN.20231006103027.err',5,'a01l_20000101_fc0_1_2_MHM,a01l_20000101_fc0_1_2_URBAN','');
INSERT INTO job_data VALUES(27,1,'a01l_20000101_fc0_2_1_OPA_2TMIN','2023-10-06-10:30:00','2023-10-06-10:30:28',1696581000,1696581000,1696581005,'COMPLETED',2,1,'00:00','debug',0,'2000-01-01 00:00:00','OPA_2TMIN','fc0',2,1,'LOCAL',17764,'',0,33,0.0,0.0,'a01l_20000101_fc0_2_1_OPA_2TMIN.20231006103027.out','a01l_20000101_fc0_2_1_OPA_2TMIN.20231006103027.err',5,'a01l_20000101_fc0_2_1_URBAN,a01l_20000101_fc0_2_1_MHM','');
INSERT INTO job_data VALUES(28,1,'a01l_20000101_fc0_2_2_OPA_2TMIN','2023-10-06-10:30:00','2023-10-06-10:30:28',1696581000,1696581000,1696581005,'COMPLETED',2,1,'00:00','debug',0,'2000-01-01 00:00:00','OPA_2TMIN','fc0',2,1,'LOCAL',17786,'',0,33,0.0,0.0,'a01l_20000101_fc0_2_2_OPA_2TMIN.20231006103028.out','a01l_20000101_fc0_2_2_OPA_2TMIN.20231006103028.err',5,'a01l_20000101_fc0_2_2_URBAN,a01l_20000101_fc0_2_2_MHM','');
INSERT INTO job_data VALUES(29,1,'a01l_20000101_fc0_1_1_OPA_2TMAX','2023-10-06-10:30:00','2023-10-06-10:30:27',1696581000,1696581000,1696581005,'COMPLETED',2,1,'00:00','debug',0,'2000-01-01 00:00:00','OPA_2TMAX','fc0',1,1,'LOCAL',17808,'',0,33,0.0,0.0,'a01l_20000101_fc0_1_1_OPA_2TMAX.20231006103027.out','a01l_20000101_fc0_1_1_OPA_2TMAX.20231006103027.err',5,'a01l_20000101_fc0_1_1_URBAN','');
INSERT INTO job_data VALUES(30,1,'a01l_20000101_fc0_1_2_OPA_2TMAX','2023-10-06-10:30:00','2023-10-06-10:30:27',1696581000,1696581000,1696581005,'COMPLETED',2,1,'00:00','debug',0,'2000-01-01 00:00:00','OPA_2TMAX','fc0',1,1,'LOCAL',17830,'',0,33,0.0,0.0,'a01l_20000101_fc0_1_2_OPA_2TMAX.20231006103027.out','a01l_20000101_fc0_1_2_OPA_2TMAX.20231006103027.err',5,'a01l_20000101_fc0_1_2_URBAN','');
INSERT INTO job_data VALUES(31,1,'a01l_20000101_fc0_2_1_OPA_2TMAX','2023-10-06-10:30:00','2023-10-06-10:30:27',1696581000,1696581000,1696581005,'COMPLETED',2,1,'00:00','debug',0,'2000-01-01 00:00:00','OPA_2TMAX','fc0',2,1,'LOCAL',17852,'',0,33,0.0,0.0,'a01l_20000101_fc0_2_1_OPA_2TMAX.20231006103027.out','a01l_20000101_fc0_2_1_OPA_2TMAX.20231006103027.err',5,'a01l_20000101_fc0_2_1_URBAN','');
INSERT INTO job_data VALUES(32,1,'a01l_20000101_fc0_2_2_OPA_2TMAX','2023-10-06-10:30:00','2023-10-06-10:30:27',1696581000,1696581000,1696581005,'COMPLETED',2,1,'00:00','debug',0,'2000-01-01 00:00:00','OPA_2TMAX','fc0',2,1,'LOCAL',17874,'',0,33,0.0,0.0,'a01l_20000101_fc0_2_2_OPA_2TMAX.20231006103027.out','a01l_20000101_fc0_2_2_OPA_2TMAX.20231006103027.err',5,'a01l_20000101_fc0_2_2_URBAN','');
INSERT INTO job_data VALUES(33,1,'a01l_20000101_fc0_1_1_MHM','2023-10-06-10:30:28','2023-10-06-10:30:56',1696581028,1696581028,1696581033,'COMPLETED',2,1,'00:00','debug',0,'2000-01-01 00:00:00','MHM','fc0',1,1,'LOCAL',17994,'',0,33,0.0,0.0,'a01l_20000101_fc0_1_1_MHM.20231006103056.out','a01l_20000101_fc0_1_1_MHM.20231006103056.err',5,'','');
INSERT INTO job_data VALUES(34,1,'a01l_20000101_fc0_1_2_MHM','2023-10-06-10:30:28','2023-10-06-10:30:56',1696581028,1696581028,1696581033,'COMPLETED',2,1,'00:00','debug',0,'2000-01-01 00:00:00','MHM','fc0',1,1,'LOCAL',18016,'',0,33,0.0,0.0,'a01l_20000101_fc0_1_2_MHM.20231006103056.out','a01l_20000101_fc0_1_2_MHM.20231006103056.err',5,'','');
INSERT INTO job_data VALUES(35,1,'a01l_20000101_fc0_2_1_MHM','2023-10-06-10:30:28','2023-10-06-10:30:56',1696581028,1696581028,1696581033,'COMPLETED',2,1,'00:00','debug',0,'2000-01-01 00:00:00','MHM','fc0',2,1,'LOCAL',18038,'',0,33,0.0,0.0,'a01l_20000101_fc0_2_1_MHM.20231006103056.out','a01l_20000101_fc0_2_1_MHM.20231006103056.err',5,'','');
INSERT INTO job_data VALUES(36,1,'a01l_20000101_fc0_2_2_MHM','2023-10-06-10:30:28','2023-10-06-10:30:56',1696581028,1696581028,1696581033,'COMPLETED',2,1,'00:00','debug',0,'2000-01-01 00:00:00','MHM','fc0',2,1,'LOCAL',18060,'',0,33,0.0,0.0,'a01l_20000101_fc0_2_2_MHM.20231006103056.out','a01l_20000101_fc0_2_2_MHM.20231006103056.err',5,'','');
INSERT INTO job_data VALUES(37,1,'a01l_20000101_fc0_1_1_URBAN','2023-10-06-10:30:28','2023-10-06-10:30:55',1696581028,1696581028,1696581033,'COMPLETED',2,1,'00:00','debug',0,'2000-01-01 00:00:00','URBAN','fc0',1,1,'LOCAL',18082,'',0,33,0.0,0.0,'a01l_20000101_fc0_1_1_URBAN.20231006103055.out','a01l_20000101_fc0_1_1_URBAN.20231006103055.err',5,'','');
INSERT INTO job_data VALUES(38,1,'a01l_20000101_fc0_1_2_URBAN','2023-10-06-10:30:29','2023-10-06-10:30:55',1696581029,1696581029,1696581034,'COMPLETED',2,1,'00:00','debug',0,'2000-01-01 00:00:00','URBAN','fc0',1,1,'LOCAL',18106,'',0,33,0.0,0.0,'a01l_20000101_fc0_1_2_URBAN.20231006103055.out','a01l_20000101_fc0_1_2_URBAN.20231006103055.err',5,'','');
INSERT INTO job_data VALUES(39,1,'a01l_20000101_fc0_2_1_URBAN','2023-10-06-10:30:29','2023-10-06-10:30:55',1696581029,1696581029,1696581034,'COMPLETED',2,1,'00:00','debug',0,'2000-01-01 00:00:00','URBAN','fc0',2,1,'LOCAL',18128,'',0,33,0.0,0.0,'a01l_20000101_fc0_2_1_URBAN.20231006103055.out','a01l_20000101_fc0_2_1_URBAN.20231006103055.err',5,'','');
INSERT INTO job_data VALUES(40,1,'a01l_20000101_fc0_2_2_URBAN','2023-10-06-10:30:29','2023-10-06-10:30:56',1696581029,1696581029,1696581034,'COMPLETED',2,1,'00:00','debug',0,'2000-01-01 00:00:00','URBAN','fc0',2,1,'LOCAL',18150,'',0,33,0.0,0.0,'a01l_20000101_fc0_2_2_URBAN.20231006103055.out','a01l_20000101_fc0_2_2_URBAN.20231006103055.err',5,'','');
DELETE FROM sqlite_sequence;
INSERT INTO sqlite_sequence VALUES('experiment_run',38);
INSERT INTO sqlite_sequence VALUES('job_data',40);
CREATE INDEX ID_JOB_NAME ON job_data(job_name);
COMMIT;
